@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from Acquisition import Explicit
 from datetime import date
 from datetime import datetime
@@ -21,14 +20,12 @@ import pytz
 import unittest
 
 
-TEST_TIMEZONE = 'Europe/Vienna'
-TEST_IMAGE = pkg_resources.resource_filename(
-    u'plone.app.caching.tests', u'test.gif')
+TEST_TIMEZONE = "Europe/Vienna"
+TEST_IMAGE = pkg_resources.resource_filename("plone.app.caching.tests", "test.gif")
 
 
 def stable_now():
-    """Patch localized_now to allow stable results in tests.
-    """
+    """Patch localized_now to allow stable results in tests."""
     tzinfo = pytz.timezone(TEST_TIMEZONE)
     now = datetime(2013, 5, 5, 10, 0, 0).replace(microsecond=0)
     now = tzinfo.localize(now)  # set tzinfo with correct DST offset
@@ -36,20 +33,22 @@ def stable_now():
 
 
 def normalize_etag(value):
-    split_value = value.split('|')
+    split_value = value.split("|")
     # The last component is expected to be the resourceRegistries ETag,
     # which is a time-based component, making it hard to test.
     last = split_value.pop()
     if str(date.today().year) in last:
         # yes, this is time based, remove it
-        return '|'.join(split_value)
+        value = "|".join(split_value)
+        return f'{value}|"'
     # return original
     return value
 
 
 def test_image():
     from plone.namedfile.file import NamedBlobImage
-    with open(TEST_IMAGE, 'rb') as myfile:
+
+    with open(TEST_IMAGE, "rb") as myfile:
         return NamedBlobImage(
             data=myfile.read(),
             filename=TEST_IMAGE,
@@ -58,8 +57,7 @@ def test_image():
 
 @implementer(IBrowserDefault, IDynamicType)
 class DummyContent(Explicit):
-
-    def __init__(self, portal_type='testtype', defaultView='defaultView'):
+    def __init__(self, portal_type="testtype", defaultView="defaultView"):
         self.portal_type = portal_type
         self._defaultView = defaultView
 
@@ -71,29 +69,27 @@ class DummyNotContent(Explicit):
     pass
 
 
-class DummyFTI(object):
-
-    def __init__(self, portal_type, viewAction=''):
+class DummyFTI:
+    def __init__(self, portal_type, viewAction=""):
         self.id = portal_type
         self._actions = {
-            'object/view': {'url': viewAction},
+            "object/view": {"url": viewAction},
         }
 
     def getActionInfo(self, name):
         return self._actions[name]
 
     def queryMethodID(self, id, default=None, context=None):
-        if id == '(Default)':
-            return 'defaultView'
-        elif id == 'view':
-            return '@@defaultView'
+        if id == "(Default)":
+            return "defaultView"
+        elif id == "view":
+            return "@@defaultView"
         return default
 
 
 @implementer(IDynamicType)
 class DummyNotBrowserDefault(Explicit):
-
-    def __init__(self, portal_type='testtype', viewAction=''):
+    def __init__(self, portal_type="testtype", viewAction=""):
         self.portal_type = portal_type
         self._viewAction = viewAction
 
@@ -102,7 +98,6 @@ class DummyNotBrowserDefault(Explicit):
 
 
 class TestIsPurged(unittest.TestCase):
-
     layer = UNIT_TESTING
 
     def setUp(self):
@@ -123,7 +118,7 @@ class TestIsPurged(unittest.TestCase):
         registry.registerInterface(IPloneCacheSettings)
 
         ploneSettings = registry.forInterface(IPloneCacheSettings)
-        ploneSettings.purgedContentTypes = ('testtype',)
+        ploneSettings.purgedContentTypes = ("testtype",)
 
         content = DummyNotContent()
         self.assertFalse(isPurged(content))
@@ -134,7 +129,10 @@ class TestIsPurged(unittest.TestCase):
         registry.registerInterface(IPloneCacheSettings)
 
         ploneSettings = registry.forInterface(IPloneCacheSettings)
-        ploneSettings.purgedContentTypes = ('File', 'Image',)
+        ploneSettings.purgedContentTypes = (
+            "File",
+            "Image",
+        )
 
         content = DummyContent()
         self.assertFalse(isPurged(content))
@@ -145,14 +143,17 @@ class TestIsPurged(unittest.TestCase):
         registry.registerInterface(IPloneCacheSettings)
 
         ploneSettings = registry.forInterface(IPloneCacheSettings)
-        ploneSettings.purgedContentTypes = ('File', 'Image', 'testtype',)
+        ploneSettings.purgedContentTypes = (
+            "File",
+            "Image",
+            "testtype",
+        )
 
         content = DummyContent()
         self.assertTrue(isPurged(content))
 
 
 class TestGetObjectDefaultPath(unittest.TestCase):
-
     layer = UNIT_TESTING
 
     def test_not_content(self):
@@ -161,22 +162,20 @@ class TestGetObjectDefaultPath(unittest.TestCase):
 
     def test_browserdefault(self):
         context = DummyContent()
-        self.assertEqual('defaultView', getObjectDefaultView(context))
+        self.assertEqual("defaultView", getObjectDefaultView(context))
 
     def test_browserviewdefault(self):
-        context = DummyContent(defaultView='@@defaultView')
-        self.assertEqual('defaultView', getObjectDefaultView(context))
+        context = DummyContent(defaultView="@@defaultView")
+        self.assertEqual("defaultView", getObjectDefaultView(context))
 
     def test_not_IBrowserDefault_methodid(self):
-        context = DummyNotBrowserDefault(
-            'testtype', 'string:${object_url}/view')
-        self.assertEqual('defaultView', getObjectDefaultView(context))
+        context = DummyNotBrowserDefault("testtype", "string:${object_url}/view")
+        self.assertEqual("defaultView", getObjectDefaultView(context))
 
     def test_not_IBrowserDefault_default_method(self):
-        context = DummyNotBrowserDefault('testtype', 'string:${object_url}/')
-        self.assertEqual('defaultView', getObjectDefaultView(context))
+        context = DummyNotBrowserDefault("testtype", "string:${object_url}/")
+        self.assertEqual("defaultView", getObjectDefaultView(context))
 
     def test_not_IBrowserDefault_actiononly(self):
-        context = DummyNotBrowserDefault(
-            'testtype', 'string:${object_url}/defaultView')
-        self.assertEqual('defaultView', getObjectDefaultView(context))
+        context = DummyNotBrowserDefault("testtype", "string:${object_url}/defaultView")
+        self.assertEqual("defaultView", getObjectDefaultView(context))
